# Person

- [1. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > default`](#default)
- [2. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > examples`](#examples)
- [3. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > if`](#if)
- [4. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > then`](#then)
- [5. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > else`](#else)
- [6. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > anyOf`](#anyOf)
- [7. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > allOf`](#allOf)
- [8. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > not`](#not)
- [9. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > properties`](#properties)
- [10. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > patternProperties`](#patternProperties)

**Title:** Person

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

| Property                                   | Pattern | Type   | Deprecated | Definition | Title/Description |
| ------------------------------------------ | ------- | ------ | ---------- | ---------- | ----------------- |
| - [default](#default )                     | No      | string | No         | -          | default           |
| - [examples](#examples )                   | No      | string | No         | -          | examples          |
| - [if](#if )                               | No      | object | No         | -          | if                |
| - [then](#then )                           | No      | object | No         | -          | then              |
| - [else](#else )                           | No      | object | No         | -          | else              |
| - [anyOf](#anyOf )                         | No      | object | No         | -          | anyOf             |
| - [allOf](#allOf )                         | No      | object | No         | -          | allOf             |
| - [not](#not )                             | No      | object | No         | -          | not               |
| - [properties](#properties )               | No      | object | No         | -          | properties        |
| - [patternProperties](#patternProperties ) | No      | object | No         | -          | patternProperties |
|                                            |         |        |            |            |                   |

## <a name="default"></a>1. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > default`

| Type                      | `string`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** default

## <a name="examples"></a>2. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > examples`

| Type                      | `string`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** examples

## <a name="if"></a>3. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > if`

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** if

## <a name="then"></a>4. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > then`

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** then

## <a name="else"></a>5. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > else`

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** else

## <a name="anyOf"></a>6. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > anyOf`

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** anyOf

## <a name="allOf"></a>7. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > allOf`

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** allOf

## <a name="not"></a>8. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > not`

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** not

## <a name="properties"></a>9. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > properties`

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** properties

## <a name="patternProperties"></a>10. ![badge](https://img.shields.io/badge/Optional-yellow) Property `Person > patternProperties`

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** patternProperties

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date